@@ -45,27 +45,27 @@
 
 #include <dcopref.h>
 #include <dcopclient.h>
-#include <kmessagebox.h>
-#include <klocale.h>
+#include <tdemessagebox.h>
+#include <tdelocale.h>
 #include <kurl.h>
 #include <kurldrag.h>
 #include <kbookmark.h>
 #include <kbookmarkmanager.h>
-#include <kdeversion.h>
+#include <tdeversion.h>
 #include <kstandarddirs.h>
 #include <krun.h>
 #include <kprocess.h>
 #include <kiconloader.h>
 #include <kshell.h>
-#include <kpopupmenu.h>
-#include <kaction.h>
-#include <kglobalsettings.h>
+#include <tdepopupmenu.h>
+#include <tdeaction.h>
+#include <tdeglobalsettings.h>
 #include <kdebug.h>
-#include <kmenubar.h>
-#include <kfiledialog.h>
-#include <kio/job.h>
-#include <kstdaccel.h>
-#include <kglobal.h>
+#include <tdemenubar.h>
+#include <tdefiledialog.h>
+#include <tdeio/job.h>
+#include <tdestdaccel.h>
+#include <tdeglobal.h>
 
 
 IRCView::IRCView(TQWidget* parent, Server* newServer) : KTextBrowser(parent)
@@ -107,9 +107,9 @@ IRCView::IRCView(TQWidget* parent, Server* newServer) : KTextBrowser(parent)
     m_popup->setItemVisible(toggleMenuBarSeparator, false);
     copyUrlMenuSeparator = m_popup->insertSeparator();
     m_popup->setItemVisible(copyUrlMenuSeparator, false);
-    m_popup->insertItem(SmallIconSet("editcopy"),i18n("&Copy"),Copy);
+    m_popup->insertItem(SmallIconSet("edit-copy"),i18n("&Copy"),Copy);
     m_popup->insertItem(i18n("Select All"),SelectAll);
-    m_popup->insertItem(SmallIcon("find"),i18n("Find Text..."),Search);
+    m_popup->insertItem(SmallIcon("edit-find"),i18n("Find Text..."),Search);
 
     setServer(newServer);
 
@@ -118,7 +118,7 @@ IRCView::IRCView(TQWidget* parent, Server* newServer) : KTextBrowser(parent)
     if (Preferences::customTextFont())
         setFont(Preferences::textFont());
     else
-        setFont(KGlobalSettings::generalFont());
+        setFont(TDEGlobalSettings::generalFont());
 
     if (Preferences::useParagraphSpacing()) enableParagraphSpacing();
 
@@ -175,7 +175,7 @@ void IRCView::setServer(Server* newServer)
 
     if (newServer)
     {
-        KAction *action = newServer->getViewContainer()->actionCollection()->action("open_logfile");
+        TDEAction *action = newServer->getViewContainer()->actionCollection()->action("open_logfile");
         Q_ASSERT(action);
         if(!action) return;
         m_popup->insertSeparator();
@@ -255,9 +255,9 @@ void IRCView::highlightedSlot(const TQString& _link)
         else if (!link.isEmpty() && !m_copyUrlMenu)
         {
             m_popup->setItemVisible(copyUrlMenuSeparator, true);
-            m_popup->insertItem(SmallIcon("editcopy"), i18n("Copy URL to Clipboard"), CopyUrl, 1);
+            m_popup->insertItem(SmallIcon("edit-copy"), i18n("Copy URL to Clipboard"), CopyUrl, 1);
             m_popup->insertItem(SmallIcon("bookmark"), i18n("Add to Bookmarks"), Bookmark, 2);
-            m_popup->insertItem(SmallIcon("filesaveas"), i18n("Save Link As..."), SaveAs, 3);
+            m_popup->insertItem(SmallIcon("document-save-as"), i18n("Save Link As..."), SaveAs, 3);
             m_copyUrlMenu = true;
             m_urlToCopy = link;
         }
@@ -304,7 +304,7 @@ void IRCView::openLink(const TQString& url, bool newTab)
                 TQCString foundApp, foundObj;
                 TQByteArray data;
                 TQDataStream str(data, IO_WriteOnly);
-                if( KApplication::dcopClient()->findObject("konqueror*", "konqueror-mainwindow*",
+                if( TDEApplication::dcopClient()->findObject("konqueror*", "konqueror-mainwindow*",
                     "windowCanBeUsedForTab()", data, foundApp, foundObj, false, 3000))
                 {
                     DCOPRef ref(foundApp, foundObj);
@@ -318,14 +318,14 @@ void IRCView::openLink(const TQString& url, bool newTab)
         {
             TQString cmd = Preferences::webBrowserCmd();
             cmd.replace("%u", url);
-            KProcess *proc = new KProcess;
+            TDEProcess *proc = new TDEProcess;
             TQStringList cmdAndArgs = KShell::splitArgs(cmd);
             *proc << cmdAndArgs;
             //      This code will also work, but starts an extra shell process.
             //      kdDebug() << "IRCView::urlClickSlot(): cmd = " << cmd << endl;
             //      *proc << cmd;
             //      proc->setUseShell(true);
-            proc->start(KProcess::DontCare);
+            proc->start(TDEProcess::DontCare);
             delete proc;
         }
     }
@@ -934,7 +934,7 @@ void IRCView::appendServerMessage(const TQString& type, const TQString& message,
     if(Preferences::fixedMOTD() && !m_fontDataBase.isFixedPitch(font().family()))
     {
         if(type == i18n("MOTD"))
-            fixed=" face=\"" + KGlobalSettings::fixedFont().family() + "\"";
+            fixed=" face=\"" + TDEGlobalSettings::fixedFont().family() + "\"";
     }
 
     TQString line;
@@ -1306,8 +1306,8 @@ bool IRCView::contextMenu(TQContextMenuEvent* ce)
     }
     else
     {
-        KActionCollection* actionCollection = KonversationApplication::instance()->getMainWindow()->actionCollection();
-        KToggleAction* toggleMenuBarAction = static_cast<KToggleAction*>(actionCollection->action("options_show_menubar"));
+        TDEActionCollection* actionCollection = KonversationApplication::instance()->getMainWindow()->actionCollection();
+        TDEToggleAction* toggleMenuBarAction = static_cast<TDEToggleAction*>(actionCollection->action("options_show_menubar"));
 
         if (toggleMenuBarAction && !toggleMenuBarAction->isChecked())
         {
@@ -1317,7 +1317,7 @@ bool IRCView::contextMenu(TQContextMenuEvent* ce)
 
         m_popup->setItemEnabled(Copy,(hasSelectedText()));
 
-        KAction* channelSettingsAction = 0;
+        TDEAction* channelSettingsAction = 0;
 
         if (m_chatWin->getType() == ChatWindow::Channel)
         {
@@ -1344,7 +1344,7 @@ bool IRCView::contextMenu(TQContextMenuEvent* ce)
                 break;
             case CopyUrl:
             {
-                TQClipboard *cb = KApplication::kApplication()->clipboard();
+                TQClipboard *cb = TDEApplication::kApplication()->clipboard();
                 cb->setText(m_urlToCopy,TQClipboard::Selection);
                 cb->setText(m_urlToCopy,TQClipboard::Clipboard);
                 break;
@@ -1386,9 +1386,9 @@ bool IRCView::contextMenu(TQContextMenuEvent* ce)
 
 void IRCView::setupNickPopupMenu()
 {
-    m_nickPopup = new KPopupMenu(this,"nicklist_context_menu");
-    m_modes = new KPopupMenu(this,"nicklist_modes_context_submenu");
-    m_kickban = new KPopupMenu(this,"nicklist_kick_ban_context_submenu");
+    m_nickPopup = new TDEPopupMenu(this,"nicklist_context_menu");
+    m_modes = new TDEPopupMenu(this,"nicklist_modes_context_submenu");
+    m_kickban = new TDEPopupMenu(this,"nicklist_kick_ban_context_submenu");
     m_nickPopupId= m_nickPopup->insertTitle(m_currentNick);
 
     m_nickPopup->insertItem(i18n("&Whois"),Konversation::Whois);
@@ -1469,7 +1469,7 @@ void IRCView::updateNickMenuEntries(TQPopupMenu* popup, const TQString& nickname
 
 void IRCView::setupQueryPopupMenu()
 {
-    m_nickPopup = new KPopupMenu(this,"query_context_menu");
+    m_nickPopup = new TDEPopupMenu(this,"query_context_menu");
     m_nickPopupId = m_nickPopup->insertTitle(m_currentNick);
     m_nickPopup->insertItem(i18n("&Whois"),Konversation::Whois);
     m_nickPopup->insertItem(i18n("&Version"),Konversation::Version);
@@ -1491,7 +1491,7 @@ void IRCView::setupQueryPopupMenu()
 
 void IRCView::setupChannelPopupMenu()
 {
-    m_channelPopup = new KPopupMenu(this,"channel_context_menu");
+    m_channelPopup = new TDEPopupMenu(this,"channel_context_menu");
     m_channelPopupId = m_channelPopup->insertTitle(m_currentChannel);
     m_channelPopup->insertItem(i18n("&Join"),Konversation::Join);
     m_channelPopup->insertItem(i18n("Get &user list"),Konversation::Names);
@@ -1712,7 +1712,7 @@ TQString IRCView::timeStamp()
             TQDate date = TQDate::currentDate();
             timeString = TQString("<font color=\"" +
                 timeColor + "\">[%1 %2]</font> ")
-                    .arg(KGlobal::locale()->formatDate(date, true /*short format*/),
+                    .arg(TDEGlobal::locale()->formatDate(date, true /*short format*/),
                          time.toString(timeFormat));
         }
 
@@ -1738,13 +1738,13 @@ void IRCView::keyPressEvent(TQKeyEvent* e)
 {
     KKey key(e);
 
-    if (KStdAccel::copy().contains(key))
+    if (TDEStdAccel::copy().contains(key))
     {
         copy();
         e->accept();
         return;
     }
-    else if (KStdAccel::paste().contains(key))
+    else if (TDEStdAccel::paste().contains(key))
     {
         emit textPasted(false);
         e->accept();
@@ -1782,7 +1782,7 @@ void IRCView::saveLinkAs(const TQString& url)
         return;
 
     KURL destination = dialog.selectedURL();
-    KIO::copyAs(source, destination);
+    TDEIO::copyAs(source, destination);
 }
 
 #include "ircview.moc"
