@@ -36,13 +36,13 @@
 #include <tqfileinfo.h>
 
 #include <kdebug.h>
-#include <kcmdlineargs.h>
-#include <kconfig.h>
+#include <tdecmdlineargs.h>
+#include <tdeconfig.h>
 #include <dcopclient.h>
-#include <kdeversion.h>
+#include <tdeversion.h>
 #include <kstandarddirs.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <kiconloader.h>
 
 
@@ -73,7 +73,7 @@ KonversationApplication::~KonversationApplication()
 
 int KonversationApplication::newInstance()
 {
-    KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
+    TDECmdLineArgs* args = TDECmdLineArgs::parsedArgs();
     TQCString url;
     if (args->count() > 0) url = args->arg(0);
 
@@ -207,7 +207,7 @@ int KonversationApplication::newInstance()
 
 KonversationApplication* KonversationApplication::instance()
 {
-    return static_cast<KonversationApplication*>(KApplication::kApplication());
+    return static_cast<KonversationApplication*>(TDEApplication::kApplication());
 }
 
 void KonversationApplication::prepareShutdown()
@@ -274,7 +274,7 @@ void KonversationApplication::dcopInfo(const TQString& string)
 void KonversationApplication::readOptions()
 {
     // get standard config file
-    KConfig* config=kapp->config();
+    TDEConfig* config=kapp->config();
 
     // read nickname sorting order for channel nick lists
     config->setGroup("Sort Nicknames");
@@ -543,7 +543,7 @@ void KonversationApplication::readOptions()
 
 void KonversationApplication::saveOptions(bool updateGUI)
 {
-    KConfig* config=kapp->config();
+    TDEConfig* config=kapp->config();
 
 //    Should be handled in NicklistBehaviorConfigController now
 //    config->setGroup("Sort Nicknames");
