@@ -31,16 +31,16 @@
 #include <tqvaluelist.h>
 #include <tqtextcodec.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
-#include <kio/passdlg.h>
-#include <kconfig.h>
-#include <kdeversion.h>
+#include <tdeio/passdlg.h>
+#include <tdeconfig.h>
+#include <tdeversion.h>
 #include <kshell.h>
-#include <ksocketaddress.h>
+#include <tdesocketaddress.h>
 #include <kresolver.h>
 #include <kreverseresolver.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 
 
 namespace Konversation
@@ -326,7 +326,7 @@ namespace Konversation
 
     OutputFilterResult OutputFilter::parseShowTuner(const TQString &parameter)
     {
-        KonversationApplication *konvApp = static_cast<KonversationApplication*>(KApplication::kApplication());
+        KonversationApplication *konvApp = static_cast<KonversationApplication*>(TDEApplication::kApplication());
         OutputFilterResult result;
 
         if(parameter.isEmpty() || parameter == "on")
@@ -953,7 +953,7 @@ namespace Konversation
         return result;
     }
 
-    OutputFilterResult OutputFilter::resumeRequest(const TQString &sender,const TQString &fileName,const TQString &port,KIO::filesize_t startAt)
+    OutputFilterResult OutputFilter::resumeRequest(const TQString &sender,const TQString &fileName,const TQString &port,TDEIO::filesize_t startAt)
     {
         TQString niftyFileName(fileName);
 
@@ -1127,7 +1127,7 @@ namespace Konversation
             TQString password;
             bool keep = false;
 
-            int ret = KIO::PasswordDialog::getNameAndPassword
+            int ret = TDEIO::PasswordDialog::getNameAndPassword
                 (
                 nick,
                 password,
@@ -1137,7 +1137,7 @@ namespace Konversation
                 i18n("IRC Operator Password")
                 );
 
-            if(ret == KIO::PasswordDialog::Accepted)
+            if(ret == TDEIO::PasswordDialog::Accepted)
             {
                 result.toServer = "OPER " + nick + ' ' + password;
             }
